@@ -2,6 +2,7 @@ import os
 from mako.template import Template
 from pathlib import Path
 from . import utils
+from . import parser_mako
 import collections
 from lupa import *
 
@@ -299,14 +300,18 @@ class BaseParser:
     def render_mako(self, fime_name, mako_name, context):
         file_path = os.path.join(self.out_path, context.name + fime_name)
         file = utils.open_file(file_path + '.py', 'w')
-        template = Template(filename=str(self.mako_path / mako_name),
-                            module_directory=os.path.join(self.script_path, 'makoCache'))
+        template = self.get_render_mako_template(mako_name)
         content = self.template_render(template, context)
         content = content.replace('\n', '')
         content = content.replace('\r\n', '')
         file.write(content)
         file.close()
 
+    def get_render_mako_template(self, mako_name):
+        template = Template(text= eval('parser_mako.' + mako_name, globals(), locals()),
+                            module_directory=os.path.join(self.script_path, 'makoCache'))
+        return template
+
     def template_render(self, template, context):
         return template.render(
             context_name=context.name,
@@ -315,7 +320,7 @@ class BaseParser:
 
     def generate_context(self):
         for key, context in self.contexts.items():
-            self.render_mako("Context" , 'ecs_context.mako', context)
+            self.render_mako("Context" , 'ecs_context', context)
             file_name = os.path.join(self.out_path / "../Extension/Context", context.name + "Context.py" )
             if not os.path.exists(file_name):
                 file = utils.open_file(file_name, 'w')
@@ -328,7 +333,7 @@ class {0}Context(Context):
 
     def generate_entity(self):
         for key, context in self.contexts.items():
-            self.render_mako("Entity" , 'ecs_entity.mako', context)
+            self.render_mako("Entity" , 'ecs_entity', context)
             file_name = os.path.join(self.out_path / "../Extension/Entity", context.name + "Entity.py" )
             if not os.path.exists(file_name):
                 file = utils.open_file(file_name, 'w')
@@ -341,15 +346,14 @@ class {0}Entity(Entity):
 
     def generate_component(self):
         for key, context in self.contexts.items():
-            self.render_mako("Components" , 'ecs_make_component.mako', context)
+            self.render_mako("Components" , 'ecs_make_component', context)
 
     def generate_matcher(self):
         for key, context in self.contexts.items():
             self.render_mako("Matchers" , 'ecs_matcher.mako', context)
 
     def generate_autoinc(self):
-        template = Template(filename=str(self.mako_path / "ecs_autoinc.mako"),
-                            module_directory=os.path.join(self.script_path, 'makoCache'))
+        template = self.get_render_mako_template('ecs_autoinc')
         file_name = os.path.join(self.out_path, "Contexts.py" )
         file = utils.open_file(file_name, 'w')
         content = template.render(
